Struct RefContainer

pub struct RefContainer<'r, T>(/* private fields */);
Container implementation via exclusive reference to MaybeUninit

Implements ExclusiveContainer

Example

let mut tmp = MaybeUninit::uninit();
let mut container = RefContainer::init_value(&mut tmp, 42);
let shared: &i32 = &container;
let exclusive: Pin<&mut i32> = container.inner();
let mut tmp = MaybeUninit::uninit();
let container2 = container.mv::<RefContainer<_>>(&mut tmp);

Note that this container has a non-() allocator, and you might want to explicitly allocate MaybeUninit:

let mut tmp = MaybeUninit::uninit();
let container = RefContainer::init_value(&mut tmp, 42);

This works just fine too, although a bit verbose

Implementations

Source

impl<'r, T> RefContainer<'r, T>

pub fn iter<'r0>(&'r0 self) -> <&'r0 Self as IntoIterator>::IntoIter
where for<'r1> &'r1 T: IntoIterator, 'r: 'r0,

Same as <&Self as IntoIterator>::into_iter(self)