pub struct ArcContainer<T>(/* private fields */);Available on crate feature
alloc only.Expand description
Container implementation via privately implemented Arc
Example
let mut container = ArcContainer::init_value((), 42);
let shared: &i32 = &container;
let exclusive: Pin<&mut i32> = container.try_inner().expect("Single Arc should have exclusive access");
let mut container2 = container.try_mv::<ArcContainer<_>>(()).expect("Single Arc should be always successfully moved out of");
let container3 = container2.clone(); // container is not longer exclusive
assert!(container2.try_inner().is_none(), "Non-excluive Arc should not be able to get &mut");
let shared: &i32 = &container2; // shared reference is still ok
assert!(container2.try_mv::<ArcContainer<_>>(()).is_none());Implementations
Sourceimpl<T> ArcContainer<T>
impl<T> ArcContainer<T>
Sourcepub fn iter<'r0>(&'r0 self) -> <&'r0 Self as IntoIterator>::IntoIterwhere
for<'r1> &'r1 T: IntoIterator,
pub fn iter<'r0>(&'r0 self) -> <&'r0 Self as IntoIterator>::IntoIterwhere
for<'r1> &'r1 T: IntoIterator,
Same as <&Self as IntoIterator>::into_iter(self)